@@ -16,9 +16,11 @@ package Util;
 
 sub System {
     local($cmd) = $_[0];
+	local($rc);
 
     &Dbg("system(\"$cmd\")");
-    system("$cmd");
+    $rc = system("$cmd");
+	return $rc;
 }
 
 sub Dbg {
