@@ -16,31 +16,34 @@ sub usage {
 print STDERR <<"EOT"
 Usage: $prgname [options] file [[options} file] ...
 
- ASCII to Postscript Options:         Output Options:                 
- F #  fontsize in points              c #  print multiple copies (def: 1)
- B    use bold font                   p    preview output before printing
- t #  tabindent (def: 8)            P,d s  select printer (def: $printer) 
- w    wrap/fold lines if too long     o s  write to file instead of printer
- l #  lines per page (adj.fontsize)                                        
- N    line-numbers                    Printer Options:            
- H s  page header                     D    force duplex  mode
- m    visualize metachars TAB,BS,FF   S    force simplex mode 
-                                      T #  select papertray 
- DVI to Postscript Options:           M    manual paper input
- R #  resolution in DPI (def: 300)   
-                                      Special Command Options:               
- Common Layout Options:               q    display queue of specific printer 
- L    landscape mode (def: portrait)  Q    display queue of all printers     
- 2    two pages on one physical       i    information about specific printer
- 4    four pages on one physical      I    information about all printers    
- s r  print only selected pages       n    notify admin about printer trouble
- b    draw surrounding borders        h    this page                         
-                                      V    version information  
- #=number
- f=file                               General Processing Options:
- s=string                             v    verbose mode          
- r=range (#,-#,#-,#-#,r,o,e,S,B)      e    expert mode           
-                                      x    debug mode            
+ Input Options:                       Output Options:                          
+ r    remove print mode header        c #  print multiple copies (def: 1)
+ f s  apply external filter           p    preview output before printing     
+                                    P,d s  select printer (def: $printer)    
+ ASCII to Postscript Options:         o s  write to file instead of printer  
+ F #  fontsize in points                                                     
+ B    use bold font                   Printer Options:                       
+ t #  tabindent (def: 8)              D    force duplex  mode                
+ w    wrap/fold lines if too long     S    force simplex mode                
+ l #  lines per page (adj.fontsize)   T #  select papertray                  
+ N    line-numbers                    M    manual paper input                
+ H s  page header                                                            
+ m    visualize metachars TAB,BS,FF   Special Command Options:               
+                                      q    display queue of specific printer 
+ DVI to Postscript Options:           Q    display queue of all printers     
+ R #  resolution in DPI (def: 300)    i    information about specific printer
+                                      I    information about all printers    
+ Common Layout Options:               n    notify admin about printer trouble
+ L    landscape mode (def: portrait)  h    this page                         
+ 2    two pages on one physical       V    version information               
+ 4    four pages on one physical                                             
+ s r  print only selected pages       General Processing Options:            
+ b    draw surrounding borders        v    verbose mode                      
+                                      e    expert mode                       
+ #=number                             x    debug mode                        
+ f=file                             
+ s=string                          
+ r=range (#,-#,#-,#-#,r,o,e,S,B)  
 EOT
 }
 
@@ -62,6 +65,8 @@ sub Main {
 
     #   argument line parsing
     %optiondecl = (
+        'removeheader',  "r  false",
+        'filter',        "f: unset",
         'fontsize',      "F: unset",
         'boldface',      "B  false",
         'borders',       "b  false",
@@ -140,13 +145,13 @@ sub Main {
                     $option{$optname} = ($optval == 0 ? "false" : "true");
                 }
             }
-			else {
-        		$option{$optname} = $optdef;
-			}
-			# cleanup for next while(..) iteration
+            else {
+                $option{$optname} = $optdef;
+            }
+            # cleanup for next while(..) iteration
             # i.e. next time don't want to see the options of
             # an old option block
-		    eval "\$Getopts::opt_$optchar = '';"; 
+            eval "\$Getopts::opt_$optchar = '';"; 
         }
 
         #  special commands are processed at any time
@@ -155,18 +160,19 @@ sub Main {
             exit $Util::EX{'OK'};
         }
         if ($option{'version'} eq 'true') {
-            print STDERR "$Vers::Hello\n";
-            print STDERR "    [$Config::target]\n";
+            print STDERR "$Vers::NLP_Hello\n";
+            print STDERR "[$Config::target]\n";
             print STDERR "\n";
-            print STDERR "Copyright (c) 1992, 1993 [only version 1]\n";
-            print STDERR "    software design & management (sd&m) GmbH & Co KG,\n";
-            print STDERR "    All Rights Reserved.\n";
-            print STDERR "Copyright (c) 1995\n";
-            print STDERR "    Technische Universitaet Muenchen (TUM),\n";
-            print STDERR "    All Rights Reserved.\n";
-            print STDERR "Copyright (c) 1992, 1993, 1994, 1995, 1996\n";
+            print STDERR "  Copyright (c) 1992-1997\n";
             print STDERR "    Ralf S. Engelschall,\n";
             print STDERR "    All Rights Reserved.\n";
+            print STDERR "  Copyright (c) 1992-1993 [version 1 only]\n";
+            print STDERR "    software design & management (sd&m) GmbH & Co KG,\n";
+            print STDERR "    All Rights Reserved.\n";
+            print STDERR "  Copyright (c) 1995 [version 2 only]\n";
+            print STDERR "    Technische Universitaet Muenchen (TUM),\n";
+            print STDERR "    All Rights Reserved.\n";
+            print STDERR "\n";
             exit $Util::EX{'OK'};
         }
         if ($option{'queueall'} eq 'true') {
@@ -179,10 +185,10 @@ sub Main {
         }
 
         #  be careful, the underlying
-    	if ($option{'pageheader'} ne '' && length($option{'pageheader'}) > 35) {
+        if ($option{'pageheader'} ne '' && length($option{'pageheader'}) > 35) {
            print STDERR "Sorry, pageheaders can be max. 35 characters long\n";
            exit $Util::EX{'FAIL'};
-    	}
+        }
 
         if ($option{'printer'} eq 'unset' && $option{'printerd'} ne 'unset') {
             $option{'printer'} = $option{'printerd'};
